package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.ClewImg;

/**
 * 线索图片Service接口
 *
 * @author ruoyi
 * @date 2023-11-06
 */
public interface IClewImgService
{
    /**
     * 查询线索图片
     *
     * @param id 线索图片主键
     * @return 线索图片
     */
    public ClewImg selectClewImgById(Long id);

    /**
     * 查询线索图片列表
     *
     * @param clewImg 线索图片
     * @return 线索图片集合
     */
    public List<ClewImg> selectClewImgList(ClewImg clewImg);

    /**
     * 新增线索图片
     *
     * @param clewImg 线索图片
     * @return 结果
     */
    public int insertClewImg(ClewImg clewImg);

    /**
     * 修改线索图片
     *
     * @param clewImg 线索图片
     * @return 结果
     */
    public int updateClewImg(ClewImg clewImg);

    /**
     * 批量删除线索图片
     *
     * @param ids 需要删除的线索图片主键集合
     * @return 结果
     */
    public int deleteClewImgByIds(String ids);

    /**
     * 删除线索图片信息
     *
     * @param id 线索图片主键
     * @return 结果
     */
    public int deleteClewImgById(Long id);
}
